@@ -6,11 +6,16 @@
 #' @format \code{\link{R6Class}} object.
 #' @section General Methods:
 #' \describe{
-#'  \item{\code{new(url, user, pwd, logger)}}{
+#'  \item{\code{new(url, user, pwd, logger, keyring_backend)}}{
 #'    This method is used to instantiate an ocsManager. The user/pwd are
-#'    mandatory in order to connect to 'ocs'. The logger can be either
-#'    NULL, "INFO" (with minimum logs), or "DEBUG" (for complete curl 
-#'    http calls logs)
+#'    mandatory in order to connect to 'ocs'. 
+#'    
+#'    The logger can be either NULL, "INFO" (with minimum logs), or "DEBUG" 
+#'    (for complete curl http calls logs).
+#'    
+#'    The \code{keyring_backend} can be set to use a different backend for storing 
+#'    the user password with \pkg{keyring} (Default value is 'env').
+#'   
 #'  }
 #'  \item{\code{connect()}}{
 #'    A method to connect to 'ocs' and set version/capabilities
@@ -138,13 +143,23 @@ ocsManager <-  R6Class("ocsManager",
   private = list(
     url = NULL,
     user = NULL,
-    token = NULL,
     cookies = NULL,
     version = NULL,
     capabilities = NULL,
     
+    keyring_backend = NULL,
     keyring_service = NULL,
     
+    #getToken (if existing)
+    getToken = function(){
+      token <- NULL
+      if(!is.null(private$keyring_service)){
+        keyring_token <- suppressWarnings(try(private$keyring_backend$get(service = private$keyring_service, username = paste0(private$user, "_token")), silent = TRUE))
+        if(!is(keyring_token, "try-error")) token <- keyring_token
+      }
+      return(token)
+    },
+    
     #checkAPIAvailability
     checkAPIAvailability = function(name, element){
       if(!private$capabilities[[element]]$api_enabled){
@@ -162,12 +177,19 @@ ocsManager <-  R6Class("ocsManager",
   ),
   public = list(
     apis = list(),
-    initialize = function(url, user, pwd, logger = NULL){
+    initialize = function(url, user, pwd, logger = NULL,
+                          keyring_backend = 'env'){
       super$initialize(logger = logger)
       private$url = url
       private$user <- user
+      if(!keyring_backend %in% names(keyring:::known_backends)){
+        errMsg <- sprintf("Backend '%s' is not a known keyring backend!", keyring_backend)
+        self$ERROR(errMsg)
+        stop(errMsg)
+      }
+      private$keyring_backend <- keyring:::known_backends[[keyring_backend]]$new()
       private$keyring_service <- paste0("ocs4R@", url)
-      keyring::key_set_with_value(private$keyring_service, username = user, password = pwd)
+      private$keyring_backend$set_with_value(private$keyring_service, username = paste0(user,"_pwd"), password = pwd)
       
       #try to connect
       if(!startsWith(self$getClassName(), "ocsApi")){
@@ -180,7 +202,7 @@ ocsManager <-  R6Class("ocsManager",
         supportedManagers <- list_of_classes[regexpr("ocsApi.+Manager", list_of_classes)>0]
         for(manager in supportedManagers){
           class <- eval(parse(text=manager))
-          man <- class$new(url, user, pwd, logger)
+          man <- class$new(url, user, pwd, logger, keyring_backend)
           api_name <- tolower(unlist(strsplit(unlist(strsplit(manager, "ocsApi"))[2],"Manager"))[1])
           self$apis[[api_name]] <- man
           list_of_methods <- rev(names(man))
@@ -200,7 +222,8 @@ ocsManager <-  R6Class("ocsManager",
     connect = function(){
       caps_req <- ocsRequest$new(
         type = "HTTP_GET", private$url, "ocs/v1.php/cloud/capabilities",
-        private$user, logger = self$loggerType
+        private$user, pwd = private$keyring_backend$get(service = private$keyring_service, username = paste0(private$user,"_pwd")), 
+        logger = self$loggerType
       )
       caps_req$execute()
       caps_resp <- caps_req$getResponse()
@@ -209,15 +232,17 @@ ocsManager <-  R6Class("ocsManager",
       cookies <- as.list(req_cookies$value)
       names(cookies) <- req_cookies$name
       if(length(cookies[names(cookies)=="XSRF-TOKEN"])>0){
-        private$token <- cookies[names(cookies)=="XSRF-TOKEN"][[1]]
+        token <- cookies[names(cookies)=="XSRF-TOKEN"][[1]]
+        private$keyring_backend$set_with_value(private$keyring_service, username = paste0(private$user,"_token"), password = token)
       }
       cookies <- unlist(cookies[names(cookies)!="XSRF-TOKEN"])
       private$cookies <- paste0(sapply(names(cookies), function(cookiename){paste0(cookiename,"=",cookies[[cookiename]])}),collapse=";")
       
-      if(!is.null(private$token)){
+      keyring_token <- private$getToken()
+      if(!is.null(keyring_token)){
         caps_req <- ocsRequest$new(
           type = "HTTP_GET", private$url, "ocs/v1.php/cloud/capabilities",
-          private$user, token = private$token, cookies = private$cookies, 
+          private$user, token = keyring_token, cookies = private$cookies, 
           logger = self$loggerType
         )
         caps_req$execute()
